﻿using Syncfusion.UI.Xaml.TreeGrid;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;

namespace EditingDemo
{
    public static class Commands
    {
        static Commands()
        {
            CommandManager.RegisterClassCommandBinding(typeof(SfTreeGrid), new CommandBinding(AddItemParentGrid, OnAddItemParentGrid));
            CommandManager.RegisterClassCommandBinding(typeof(SfTreeGrid), new CommandBinding(RemoveItemParentGrid, OnRemoveItemParentGrid));
            CommandManager.RegisterClassCommandBinding(typeof(SfTreeGrid), new CommandBinding(AddChildItemParentGrid, OnAddChildItemParentGrid));
            CommandManager.RegisterClassCommandBinding(typeof(SfTreeGrid), new CommandBinding(RemoveChildItemParentGrid, OnRemoveChildItemParentGrid));
        }

        public static RoutedCommand AddItemParentGrid = new RoutedCommand("AddItem_ParentGrid", typeof(SfTreeGrid));
        public static RoutedCommand RemoveItemParentGrid = new RoutedCommand("RemoveItem_ParentGrid", typeof(SfTreeGrid));
        public static RoutedCommand AddChildItemParentGrid = new RoutedCommand("AddChildItem_ParentGrid", typeof(SfTreeGrid));
        public static RoutedCommand RemoveChildItemParentGrid = new RoutedCommand("RemoveChildItem_ParentGrid", typeof(SfTreeGrid));

        private static void OnAddItemParentGrid(object sender, ExecutedRoutedEventArgs args)
        {
            var empDetails = (sender as SfTreeGrid).DataContext as EmployeeRepository ;
            if (empDetails != null)
            {

                if (empDetails.EmployeeDetails == null)
                {
                    empDetails.EmployeeDetails = new ObservableCollection<Employee>();
                    empDetails.EmployeeDetails.Add(new Employee() { Id = 1001, FirstName = "Samuel", LastName = "Geroge", Salary = 29122 });
                }
                else
                    empDetails.EmployeeDetails.Insert(1, new Employee() { Id = 1002, FirstName = "Peter", LastName = "Willson", Salary = 211211 });                
            }
        }

        private static void OnRemoveItemParentGrid(object sender, ExecutedRoutedEventArgs args)
        {
            var empDetails = (sender as SfTreeGrid).DataContext as EmployeeRepository;
            var data = (sender as SfTreeGrid).View.Nodes[1].Item;
            var index = (sender as SfTreeGrid).View.Nodes.GetIndexFromData(data);
            empDetails.EmployeeDetails.RemoveAt(index);            
        }

        private static void OnAddChildItemParentGrid(object sender, ExecutedRoutedEventArgs args)
        {
            var empDetails = (sender as SfTreeGrid).DataContext as EmployeeRepository;
            //2nd level TreeNode
            var collection = empDetails.EmployeeDetails[0].Children[0].Children;
            if (collection == null)
                collection = new ObservableCollection<Employee>();
            collection.Add(new Employee() { FirstName = "Andreson", Id = 15, LastName = "Sam", Salary = 29122 });
            empDetails.EmployeeDetails[0].Children = collection;
        }

        private static void OnRemoveChildItemParentGrid(object sender, ExecutedRoutedEventArgs args)
        {
            var empDetails = (sender as SfTreeGrid).DataContext as EmployeeRepository;
            // Remove particular child node of treeGrid
            var collection = empDetails.EmployeeDetails[0].Children;
            var item = collection.FirstOrDefault(i => i.Id == 7);
            collection.Remove(item);
        }
    }    
}
